@@ -6,5 +6,6 @@ void dtrsm(
     const int *m, const int *n, const double *alpha, const double *a,
     const int *lda, double *b, const int *ldb){
   return F77_CALL(dtrsm)(
-      side, uplo, transa, diag, m, n, alpha, a, lda, b, ldb);
+      side, uplo, transa, diag, m, n, alpha, a, lda, b, ldb
+      FCONE FCONE FCONE FCONE);
 }
